@@ -27,7 +27,7 @@
 /* 関数プロトタイプ */
 RData * check_target(OPArg *, VList *, SDir *);
 void check_overwrite(const OPArg *, const SDir *, CPInfo *, CPDD *);
-struct stat * make_directory(CPInfo *, CPDD *);
+struct stat * make_directory(CPInfo *, OPArg *, CPDD *);
 static VList * dir_traverse(VList *, CPInfo *, OPArg *, SDir *, CPDD *);
 static inline void delete_last_slash(const int, char []);
 static inline CPInfo * cpinfo_malloc(void);
@@ -142,7 +142,7 @@ static inline void set_same_or_different(const VList *, const char *, const char
 		if(from_current_flag == false)\
 		{\
 			count_dire_plus(cpinfo, cpdd);\
-			stat_buf = make_directory(cpinfo, cpdd);\
+			stat_buf = make_directory(cpinfo, oparg, cpdd);\
 			file_list = append_list(file_list, (void *)cpinfo);\
 		}\
 		else \
@@ -712,7 +712,7 @@ INPUT:
 
 /*******************************************************************************
 *******************************************************************************/
-struct stat * make_directory(CPInfo *cpinfo, CPDD *cpdd)
+struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 {
 	errno = 0;
 	if(g_file_test(cpinfo->to, G_FILE_TEST_EXISTS) == TRUE)
@@ -732,6 +732,12 @@ struct stat * make_directory(CPInfo *cpinfo, CPDD *cpdd)
 	}
 	else
 	{
+		if(oparg->V == VERBOS)
+		{
+			printf("%s -> %s\n", cpinfo->from, cpinfo->to);
+			fflush(stdout);
+		}
+
 		cpinfo->write = true;
 		cpdd->mk_dir_count++;
 	}
@@ -772,7 +778,7 @@ struct stat * make_directory(CPInfo *cpinfo, CPDD *cpdd)
 {\
 	count_dire_plus(cpinfo, cpdd);\
 	cpinfo->copy_mode = cpinfo_tmp->copy_mode;\
-	struct stat *stat_buf = make_directory(cpinfo, cpdd);\
+	struct stat *stat_buf = make_directory(cpinfo, oparg, cpdd);\
 	file_list = append_list(file_list, (void *)cpinfo);\
 	/* 再帰 */ \
 	file_list = dir_traverse(file_list, cpinfo, oparg, sdir, cpdd);\
