@@ -34,6 +34,21 @@ static _Bool lseek_err;
 static _Bool read_err;
 static _Bool read_finish;
 
+#define UNLINK_MISS_FILE \
+	print_error("NODATA", __FILE__, __LINE__, cpdd);\
+	write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, false);\
+	cpinfo->write = false;\
+\
+	errno = 0;\
+	if(unlink(cpinfo->to) == -1)\
+	{\
+		if(errno != ENOENT)\
+		{\
+			print_error("unlink", __FILE__, __LINE__, cpdd);\
+			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->to);\
+		}\
+	}
+
 /* 関数プロトタイプ */
 void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd);
 static void * read_func(void *dummy);
@@ -117,30 +132,21 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 			pthread_create(&t1, NULL, read_func, (void *)&r_number);
 			pthread_join(t1, NULL);
 
+			int swap;
+
 			for(;;)
 			{
-				r_number++;
-				a_number--;
+				swap = r_number;
+				r_number = a_number;
+				a_number = swap;
+
 				pthread_create(&t1, NULL, read_func, (void *)&r_number);
 				pthread_create(&t2, NULL, append_func, (void *)&a_number);
 
 				pthread_join(t1, NULL);
 				pthread_join(t2, NULL);
 
-				if((read_finish == true) || (lseek_err == true) || (read_err == true))
-				{
-					break;
-				}
-
-				r_number--;
-				a_number++;
-				pthread_create(&t1, NULL, read_func, (void *)&r_number);
-				pthread_create(&t2, NULL, append_func, (void *)&a_number);
-
-				pthread_join(t1, NULL);
-				pthread_join(t2, NULL);
-
-				if((read_finish == true) || (lseek_err == true) || (read_err == true))
+				if((read_finish == true) || (read_err == true))
 				{
 					break;
 				}
@@ -172,22 +178,15 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 					write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, true);
 				}
 			}
+			else if(cpinfo->from_size > total)
+			{
+				fprintf(stderr, "ファイルの読み込みに失敗しました、%sを削除します\n", cpinfo->to);
+				UNLINK_MISS_FILE
+			}
 			else
 			{
 				fprintf(stderr, "ハッシュ値が一致しませんでした、%sを削除します\n", cpinfo->to);
-				print_error("NODATA", __FILE__, __LINE__, cpdd);
-				write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, false);
-				cpinfo->write = false;
-
-				errno = 0;
-				if(unlink(cpinfo->to) == -1)
-				{
-					if(errno != ENOENT)
-					{
-						print_error("unlink", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->to);
-					}
-				}
+				UNLINK_MISS_FILE
 			}
 			break;
 
@@ -227,62 +226,28 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 static void * read_func(void *dummy)
 {
 	static int i;
-	static int try_count;
-
-	dummy++;	/* コンパイル時のwarningを出さないようにするため */
-
 	i = r_number;
-	try_count = 0;
 
-	for(;;)
+	/* 
+	 * O_DIRECTを使用するとアライメントの調整などが面倒なので、
+	 * full_read や safe_read のようなエラー処理は行わない。
+	*/
+	read_size[i] = read(fd, buf[i], buffer_size_local);
+
+	if(read_size[i] == 0)
 	{
-		read_size[i] = pread(fd, buf[i], buffer_size_local, total);
-
-		if(read_size[i] == 0)
-		{
-			read_finish = true;
-			break;
-		}
-		else if((read_size[i] % psize) == 0)
-		{
-			total += read_size[i];
-
-			if(lseek(fd, read_size[i], SEEK_CUR) == -1)
-			{
-				lseek_err = true;
-				break;
-			}
-
-			break;
-		}
-		else if((read_size[i] + total) >= static_to_size)
-		{
-			total += read_size[i];
-
-			if(lseek(fd, read_size[i], SEEK_CUR) == -1)
-			{
-				lseek_err = true;
-				break;
-			}
-
-			break;
-		}
-		else
-		{
-			try_count++;
-
-			if(try_count >= 10)
-			{
-				read_err = true;
-				break;
-			}
-			else
-			{
-				continue;
-			}
-		}
+		read_finish = true;
+	}
+	else if(read_size[i] < 0)
+	{
+		read_err = true;
+	}
+	else
+	{
+		total += read_size[i];
 	}
 
+	dummy++;	/* コンパイル時のwarningを出さないようにするため */
 	return NULL;
 }
 
@@ -296,6 +261,5 @@ static void * append_func(void *dummy)
 	md5_append(&state, buf[i], read_size[i]);
 
 	dummy++;	/* コンパイル時のwarningを出さないようにするため */
-
 	return NULL;
 }
